cd /Users/jshim2/Dropbox/projects/passive_portfolio/replication_data


*******************************************************************
* Generate Aggregated Measures and Returns
*******************************************************************
foreach passive in "active" "passive" {
	use `passive'_sfq_regdata, clear	

	preserve
	collapse (mean) rebalinadja rebalouta ///
					rebalinadjd rebaloutd [aw=wtfund_cf], by(fundno yq)

	gen rebala = rebalinadja + rebalouta
	gen rebald = rebalinadjd + rebaloutd

	save `passive'_fq_measures, replace	
	restore

	drop wt
	gen wt = shares * abs(adjprc)
	replace wt = 0 if dropvar == 1
	bysort fundno yq: egen wttot = total(wt)
	replace wtfund = wt / wttot
	drop wt wttot

	collapse (mean) f1_4facalphabpsq f1_qretbenchadjbps ///
					actshare vwlannturn [aw=wtfund], by(fundno yq)
	rename f1_4facalphabpsq falpha
	rename f1_qretbenchadjbps fbenchadjret

	save `passive'_fq_rets, replace
}


*******************************************************************
* Fund-Quarter Panel Regresions
*******************************************************************

foreach passive in "active" "passive" {
	use `passive'_fund_quarters, clear

	merge 1:1 fundno yq using `passive'_fq_rets
	keep if _merge == 3
	drop _merge

	merge 1:1 fundno yq using `passive'_fq_measures
	keep if _merge == 3
	drop _merge

	gen ftradjret = fvw_ret - ftr
	gen fradjret = fvw_ret - fr
	gen fmktadjret = fvw_retmadj

	gen expratioq = vwannexp / 4
	gen fvw_retg = fvw_ret + expratioq
	gen ftradjretg = ftradjret + expratioq
	gen fradjretg = fradjret + expratioq
	gen fmktadjretg = fmktadjret + expratioq

	foreach var of varlist nextalpha fvw_ret fvw_retg ///
						   ftradjret ftradjretg fmktadjret fmktadjretg{
		gen `var'bps = `var' * 10000
	}
	
	gen nextalphabpsq = nextalphabps * 63

	foreach var of varlist nextalphabpsq ftradjretbps ftradjretgbps ///
						   fmktadjretbps fmktadjretgbps {
		drop if `var' == .
	}

	capture drop obs
	bysort yq: gen obs=_N
	drop if obs==1
	drop obs
	bysort fundno: gen obs=_N
	drop if obs==1
	drop obs

	** Table 14 and 15: Fund-quarter regressions
	local i = 1
	foreach var of varlist nextalphabpsq ftradjretbps ftradjretgbps {
		reghdfe `var' rebala rebald actshare vwlannturn, noa cluster(yq fundno)
		if `i' == 1{
			outreg2 using _regs/fqreg_`passive', replace bdec(3)
			local i = 2
		}
		else {
			outreg2 using  _regs/fqreg_`passive', append bdec(3)
		}
		reghdfe `var' rebala rebald actshare vwlannturn, absorb(fundno) cluster(yq fundno)
		outreg2 using _regs/fqreg_`passive', append bdec(3)
		reghdfe `var' rebala rebald actshare vwlannturn, absorb(yq) cluster(yq fundno)
		outreg2 using _regs/fqreg_`passive', append bdec(3)
		reghdfe `var' rebala rebald actshare vwlannturn, absorb(yq fundno) cluster(yq fundno)
		outreg2 using _regs/fqreg_`passive', append bdec(3)
	}

	compress
	save `passive'_fq_panel, replace	
}


