cd /Users/jshim2/Dropbox/projects/passive_portfolio/replication_data


*******************************************************************
* Stock-Quarter Data
*******************************************************************
foreach passive in "active" "passive" {
	use active_sfq_regdata, clear
	gen dsharesvar = dshares_alt

	gen rebalout_dollars = dsharesvar * abs(adjprc) ///
		if (addvar == 1 | dropvar == 1)
	winsor2 rebalout_dollars, cuts(.5 99.5) replace
	replace rebalout_dollars = 0 if rebalout_dollars == . & dsharesvar != .

	gen rebalin_dollars = (dsharesvar - lsharesvar * flowp) * ///
							abs(adjprc)
	replace rebalin_dollars = . if (addvar==1 | dropvar == 1)
	winsor2 rebalin_dollars, cuts(.5 99.5) replace
	replace rebalin_dollars = 0 if (addvar==1 | dropvar == 1) & dsharesvar != .

	gen dshares_dollars = dsharesvar * abs(adjprc)
	winsor2 dshares_dollars, cuts(.5 99.5) replace

	gen rebalina_dollars = rebalin_dollars 
	replace rebalina_dollars = 0 if rebalin_dollars < 0 & rebalin_dollars != .
	gen rebalind_dollars = rebalin_dollars 
	replace rebalind_dollars = 0 if rebalin_dollars > 0 & rebalin_dollars != .
	gen rebalouta_dollars = rebalout_dollars 
	replace rebalouta_dollars = 0 if rebalout_dollars < 0 & rebalout_dollars != .
	gen rebaloutd_dollars = rebalout_dollars 
	replace rebaloutd_dollars = 0 if rebalout_dollars > 0 & rebalout_dollars != .

	collapse (mean) f1_4facalphabpsq f1_qretbenchadjbps f1qretmadj ///
					actshare vwlannturn wt ///
			 		adjprc adjshrout ///
			 (sum) rebalin_dollars rebalout_dollars ///
			 	   rebalina_dollars rebalind_dollars ///
			 	   rebalouta_dollars rebaloutd_dollars ///
			 	   dshares_dollars, ///
			  by(permno yq)

	gen adjmktcap = abs(adjprc) * abs(adjshrout)
	gen rebalin_frac = rebalin_dollars / adjmktcap
	gen rebalout_frac = rebalout_dollars / adjmktcap
	gen rebalina_frac = rebalina_dollars / adjmktcap
	gen rebalind_frac = rebalind_dollars / adjmktcap
	gen rebalouta_frac = rebalouta_dollars / adjmktcap
	gen rebaloutd_frac = rebaloutd_dollars / adjmktcap
	gen rebala_frac = (rebalina_dollars + rebalouta_dollars) / adjmktcap
	gen rebald_frac = (rebalind_dollars + rebaloutd_dollars) / adjmktcap
	gen dshares_frac = dshares_dollars / adjmktcap

	save `passive'_sq_dollars, replace
}


*******************************************************************
* Stock-Quarter Regressions
*******************************************************************
use active_sq_dollars, clear

drop if f1_4facalphabpsq == .
drop if f1qretmadj == .

capture drop obs
bysort permno: gen obs=_N
drop if obs==1
drop obs
bysort yq: gen obs=_N
drop if obs==1
drop obs

* Table 24: Active Stock-Level Rebalancing
reghdfe f1_4facalphabpsq rebala_frac rebald_frac, noa cluster(permno yq)
outreg2 using _regs/sqreg_active, replace bdec(3)
reghdfe f1_4facalphabpsq rebala_frac rebald_frac, absorb(permno yq) cluster(permno yq)
outreg2 using _regs/sqreg_active, append bdec(3)
reghdfe f1qretmadj rebala_frac rebald_frac, noa cluster(permno yq)
outreg2 using _regs/sqreg_active, append bdec(3)
reghdfe f1qretmadj rebala_frac rebald_frac, absorb(permno yq) cluster(permno yq)
outreg2 using _regs/sqreg_active, append bdec(3)

gen dsharesa_frac = dshares_frac
replace dsharesa_frac = 0 if dshares_frac < 0
gen dsharesd_frac = dshares_frac
replace dsharesd_frac = 0 if dshares_frac > 0

* Table 25: Total Stock-Level Rebalancing
reghdfe f1_4facalphabpsq dsharesa_frac dsharesd_frac, noa cluster(permno yq)
outreg2 using _regs/sqreg_active_dshares, replace bdec(3)
reghdfe f1_4facalphabpsq dsharesa_frac dsharesd_frac, absorb(permno yq) cluster(permno yq)
outreg2 using _regs/sqreg_active_dshares, append bdec(3)
reghdfe f1qretmadj dsharesa_frac dsharesd_frac, noa cluster(permno yq)
outreg2 using _regs/sqreg_active_dshares, append bdec(3)
reghdfe f1qretmadj dsharesa_frac dsharesd_frac, absorb(permno yq) cluster(permno yq)
outreg2 using _regs/sqreg_active_dshares, append bdec(3)


