*global path="D:"
global path="C:\Users\mcsam"
cd "$path\Dropbox\passive_portfolio\data"


*CRSP monthly stock data: Load data on cumulative factor to adjust shares
use "$path\Dropbox\passive_portfolio\data\factor",clear
append using "$path\Dropbox\passive_portfolio\data\factor2"
rename *,lower
replace shrout=shrout*1000
foreach v of varlist cfacpr{
	replace `v'=1 if `v'==.
}
gen adjprc=prc/cfacpr
gen adjshrout=shrout*cfacshr
gen yq=yq(year(date),quarter(date))
format yq %tq
bysort permno yq (date): keep if _n==_N
rename prc prc_raw
rename shrout shrout_raw
keep permno yq prc_raw shrout_raw adjshrout adjprc
save tmfix,replace

/*restrict to the list of funds in our dataset*/
use all_fund_yq_data,clear
keep fundno
duplicates drop 
save flist,replace

*get list of 20 blocks, merge in our list
use l2,clear
merge m:1 fundno using flist
keep if _merge==3
drop _merge
save l2small,replace


** CRSP monthly stock data -- identify stocks that have a non-missing acquiring permno
use "$path\Dropbox\mainwrds\crsp\nonmissing_ac_perm",clear
rename *,lower
** Want to create a flag for whether or not they were involved in a corporate action the quarter before/after
gen yq=yq(year(date),quarter(date))
format yq %tq
keep permno yq 
duplicates drop 
save has_ac1,replace
replace yq=yq-1
save has_ac2,replace

** CRSP monthly stock data -- identify stocks that have are a acquiring permno for at least one other permno
use "$path\Dropbox\mainwrds\crsp\nonmissing_ac_perm",clear
rename *,lower
** can have multiple acperms
** Just want to create a flag for whether or not they were involved in a corporate action the quarter before/after
gen yq=yq(year(date),quarter(date))
format yq %tq
drop permno
rename acperm permno
keep permno yq 
duplicates drop 
save is_ac1,replace
replace yq=yq-1
save is_ac2,replace

*With all the filters applied, we only go up to block 13
*forvalues g=1/20{
forvalues g=1/13{
	*use l2,clear
	use l2small,clear
	keep if g20==`g'
	levelsof fundno, local(nos)
	foreach no of local nos{
	    
		display "`g' / `no'"
		clear
		*load data for that fund
		use * if fundno==`no' using ptg`g'_clean,clear

		qui{
		    count
		    *if matched to CRSP continue
			if `r(N)'>0{
				qui capture xtset permno yq 
				
				*work with adjusted shares
				rename shares shares_raw
				rename adjshr shares
				
				*identify first and last quarter fund is present
				egen minyq=min(yq)
				egen maxyq=max(yq)

				*deal with missings -- but keep track
				gen missshares=1 if shares==.
				replace shares=0 if shares==.
				
				** need to add a dummy observations for the drops -- will create an extra observation EVERY time the stock is dropped
				tsappend, add(1)
				*keep track of these
				gen dummy=1 if fundno==.
				bysort permno (yq): replace fundno=fundno[_n-1] if fundno==.
				format yq %tq
				*******
								
				gen fshares=shares
				*fill in the gaps -- this is going to be important for lagged shares for the observations previously classified as drops
				bysort permno (yq): replace fshares=fshares[_n-1] if fshares==.
				
				** Exact same # of shares reappears
				*1 quarter
				bysort permno (yq): gen flag1=1 if shares[_n-1]==shares[_n+1] & yq[_n-1]==yq[_n+1]-2 & shares==. & shares[_n-1]!=. & shares[_n+1]!=.

				*2 quarters
				** need to add qualifiers for all the missing share blocks

				*first in block
				bysort permno (yq): gen flag2=1 if shares[_n-1]==shares[_n+2] & yq[_n-1]==yq[_n+2]-3 & shares==. & shares[_n+1]==. & shares[_n-1]!=. & shares[_n+2]!=.
				
				*2nd in block
				bysort permno (yq): replace flag2=1 if shares[_n-2]==shares[_n+1] & yq[_n-2]==yq[_n+1]-3 & shares==. & shares[_n-1]==. & shares[_n-2]!=. & shares[_n+1]!=.				


				*3 quarters
				** need to add qualifiers for all the missing share blocks
				*1st in block
				bysort permno (yq): gen flag3=1 if shares[_n-1]==shares[_n+3] & yq[_n-1]==yq[_n+3]-4 & shares==. & shares[_n+1]==. & shares[_n+2]==. & shares[_n-1]!=. & shares[_n+3]!=.
				*2nd in block
				bysort permno (yq): replace flag3=1 if shares[_n-2]==shares[_n+2] & yq[_n-2]==yq[_n+2]-4 & shares==. & shares[_n+1]==. & shares[_n-1]==. & shares[_n-2]!=. & shares[_n+2]!=.
				*3rd in block
				bysort permno (yq): replace flag3=1 if shares[_n-3]==shares[_n+1] & yq[_n-3]==yq[_n+1]-4 & shares==. & shares[_n-1]==. & shares[_n-2]==.  & shares[_n-3]!=. & shares[_n+1]!=.		

				** Reappears within 10% -- again need qualifiers for block position
				*1 quarter
				bysort permno (yq): gen aflag1=1 if (abs(shares[_n+1]-shares[_n-1])/(shares[_n-1]))<0.1 & yq[_n-1]==yq[_n+1]-2 & shares==. & shares[_n-1]!=. & shares[_n+1]!=.
				
				*2 quarters
				bysort permno (yq): gen aflag2=1 if (abs(shares[_n+2]-shares[_n-1])/(shares[_n-1]))<0.1 & yq[_n-1]==yq[_n+2]-3 & shares==. & shares[_n+1]==. & shares[_n-1]!=. & shares[_n+2]!=.

				bysort permno (yq): replace aflag2=1 if (abs(shares[_n+1]-shares[_n-2])/(shares[_n-2]))<0.1 & yq[_n-2]==yq[_n+1]-3 & shares==. & shares[_n-1]==. & shares[_n-2]!=. & shares[_n+1]!=.				
				
				*3 quarters
				bysort permno (yq): gen aflag3=1 if (abs(shares[_n+3]-shares[_n-1])/(shares[_n-1]))<0.1 & yq[_n-1]==yq[_n+3]-4 & shares==. & shares[_n+1]==. & shares[_n+2]==. & shares[_n-1]!=. & shares[_n+3]!=.

				
				bysort permno (yq): replace aflag3=1 if (abs(shares[_n+2]-shares[_n-2])/(shares[_n-2]))<0.1 & yq[_n-2]==yq[_n+2]-4 & shares==. & shares[_n+1]==. & shares[_n-1]==. & shares[_n-2]!=. & shares[_n+2]!=.

				bysort permno (yq): replace aflag3=1 if (abs(shares[_n+1]-shares[_n-3])/(shares[_n-3]))<0.1 & yq[_n-3]==yq[_n+1]-4 & shares==. & shares[_n-1]==. & shares[_n-2]==. & shares[_n-3]!=. & shares[_n+1]!=.

				*all the dummy observations will have missing shares held -- so fill those in for zeros so we can identify adds/drops
				replace shares=0 if shares==. 
				
				*identify adds if not there last quarter but there now, but not in the first quarter the find exists
				gen add=1 if (shares!=. & shares!=0) & (L.shares==. | L.shares==0) & yq>minyq 
				*everything is an add if the fund was just created
				replace add=1 if yq==minyq
				
				** want to keep track of how many adds there would be if we didn't make these corrections
				gen addraw=add

				*** Identify fund with at least 1 gap
				count if flag1==1
				local num=`r(N)'


				*for flags - say it's not an actual add if the exact thing reappeared
				bysort permno (yq): replace add=. if flag1[_n-1]==1
				bysort permno (yq): replace add=. if flag2[_n-1]==1
				bysort permno (yq): replace add=. if flag3[_n-1]==1
				
				*start with the same definition above
				gen add2=1 if (shares!=. & shares!=0) & (L.shares==. | L.shares==0) & yq>minyq 
				replace add2=1 if yq==minyq
				*for flags - say it's not an add if the thing reappeared within 10%
				bysort permno (yq): replace add2=. if aflag1[_n-1]==1
				bysort permno (yq): replace add2=. if aflag2[_n-1]==1
				bysort permno (yq): replace add2=. if aflag3[_n-1]==1
								
				*identify drops if 0 this quarter, but there last quarter.  Has to be before fund dies (maybe want a different measure of drops for fund deaths)
				gen drop=1 if shares==0 & L.shares!=0 & yq<maxyq
				
				** want to keep track of how many drops there would be if we didn't make these corrections
				gen dropraw=drop
				
				*say not a drop if it reappears exactly
				bysort permno (yq): replace drop=. if flag1==1
				bysort permno (yq): replace drop=. if flag2==1
				bysort permno (yq): replace drop=. if flag3==1
				
				* again same premise for margin of error
				gen drop2=1 if shares==0 & L.shares!=0 & yq<maxyq
				*not a drop if reappears within 10%
				bysort permno (yq): replace drop2=. if aflag1==1
				bysort permno (yq): replace drop2=. if aflag2==1
				bysort permno (yq): replace drop2=. if aflag3==1

				*keep track of how many observations before applying the filter that removes the observations associated with mistaken adds and drops
				preserve
				collapse (sum) flag* aflag* add drop addraw dropraw add2 drop2,by(fundno yq)
				save counts,replace
				restore

				drop if shares==0 & drop!=1	& drop2!=1
				
				*need to hold onto "dummy" to keep track of of many synthetic observations we created for drops
				drop minyq maxyq 
				drop prc_raw shrout_raw adjshrout adjprc dheld

				/*now that we've filled in the dataset, can merge in prices -- important to do this here b/c want them for the dummy obs*/
				merge m:1 permno yq using tmfix
				keep if _merge==3
				drop _merge
				
				*check if has valid prices
				count 
				if `r(N)'>0{
					replace adjprc=abs(adjprc)

					*calculate change in shares
					qui capture xtset permno yq
					gen lshares=L.shares
					gen dshares=D.shares
					qui replace dshares=shares if add==1 
					qui replace lshares=0 if add==1
					
					*** fix dshares for things that look like drops, but we argue aren't really drops
					gen lfshares=L.fshares
					replace dshares=-1*lfshares if drop==1 & dshares==.
					* set dshares_alt missing if it looks like a fake add/drop, as far as add2 or drop2 is concerned
					gen dshares_alt=dshares
					replace dshares_alt=. if drop==1 & drop2!=1
					replace dshares_alt=. if add==1 & add2!=1
					order permno yq dshares 

					*alternative definition of dshares where we attribute the entire change to the last quarter the stock reappears
					gen dshares_alt2=dshares_alt
					bysort permno (yq): replace dshares_alt2=shares-shares[_n-2] if aflag1[_n-1]==1 & drop==1 & drop2!=1
					bysort permno (yq): replace dshares_alt2=shares-shares[_n-3] if aflag2[_n-1]==1 & aflag2[_n-2]==1 & drop==1 & drop2!=1
					bysort permno (yq): replace dshares_alt2=shares-shares[_n-4] if aflag3[_n-1]==1 & aflag3[_n-2]==1 & aflag3[_n-3]==1 & drop==1 & drop2!=1

					bysort permno (yq): replace dshares_alt2=shares-shares[_n-2] if aflag1[_n-1]==1 & add==1 & add2!=1
					bysort permno (yq): replace dshares_alt2=shares-shares[_n-3] if aflag2[_n-1]==1 & aflag2[_n-2]==1 & add==1 & add2!=1
					bysort permno (yq): replace dshares_alt2=shares-shares[_n-4] if aflag3[_n-1]==1 & aflag3[_n-2]==1 & aflag3[_n-3]==1 & add==1 & add2!=1

					*need to hold on to these variables to count changed observations
					*drop flag* aflag*
					capture drop dheld
					gen dheld=shares*abs(adjprc)
					bysort yq: egen tdheld=total(dheld)
					gen wt=dheld/tdheld
					
					** special cases with acquisisions
					*has_ac1 - dataset based on CRSP monthly stock data which identifies quarters where the permno has an acquiring permno [in quarter t]				
					merge m:1 permno yq using has_ac1
					gen has=1 if _merge==3
					drop if _merge==2
					drop _merge

					*has_ac2 - dataset based on CRSP monthly stock data which identifies quarters where the permno has an acquiring permno [in quarter t-1]
					merge m:1 permno yq using has_ac2
					replace has=1 if _merge==3
					drop if _merge==2
					drop _merge
						
					*is_ac1 - dataset based on CRSP monthly stock data which identifies quarters where the permno is an acquiring permno [in quarter t]	
					merge m:1 permno yq using is_ac1
					gen is=1 if _merge==3
					drop if _merge==2
					drop _merge

					*is_ac2 - dataset based on CRSP monthly stock data which identifies quarters where the permno is an acquiring permno [in quarter t-1]	
					merge m:1 permno yq using is_ac2
					replace is=1 if _merge==3
					drop if _merge==2
					drop _merge
					
					gen hasis=1 if has==1 | is==1
					foreach v of varlist has is hasis{
						replace `v'=0 if `v'==.
					} 
					
					*********************************************************
					*** get max index of how many times they traded the stock
					*********************************************************
					egen bindex=group(permno yq) if add==1
					bysort permno: egen minbindex=min(bindex)
					replace minbindex=minbindex-1
					replace bindex=bindex-minbindex
					drop minbindex
					bysort permno (yq): replace bindex=bindex[_n-1] if bindex==.

					egen bindex2=group(permno yq) if add2==1
					bysort permno: egen minbindex=min(bindex)
					replace minbindex=minbindex-1
					replace bindex2=bindex2-minbindex
					drop minbindex
					bysort permno (yq): replace bindex2=bindex2[_n-1] if bindex2==.						

					gen holdingperiod1=1 if add==1
					bysort permno (yq): replace holdingperiod1=holdingperiod1[_n-1]+1 if holdingperiod1==.
				
					gen holdingperiod2=1 if add2==1
					bysort permno (yq): replace holdingperiod2=holdingperiod2[_n-1]+1 if holdingperiod2==.
					
					************************************************************
					*** Calculate cost basis
					************************************************************

					*add cost basis
					gen costbasis=adjprc if add==1
					*this is going to be a bit of a disaster, b/c you need to increment 1 period at a time
					*bysort fundno permno (yq): replace costbasis=costbasis[_n-1] if shares
					*new cost basis = (old cost basis * # shares held before + new cost basis * new # of shares held)/total shares held
					bysort fundno permno (yq): replace costbasis=(costbasis[_n-1]*shares[_n-1] + adjprc*(shares-shares[_n-1]))/shares if add!=1 & shares>=shares[_n-1]

					bysort fundno permno (yq): replace costbasis=costbasis[_n-1] if add!=1 & shares<shares[_n-1]

 					bysort fundno permno (yq): replace costbasis=costbasis[_n-1] if drop==1

 					/*add rounds until zero changes made, the problem occurs if they were increasing but then not*/
 					bysort permno bindex (yq): gen inc=1 if shares<shares[_n-1] & shares[_n-1]>=shares[_n-2]
 					bysort permno bindex: egen tinc=total(inc)
 					*order bindex permno yq inc shares

 					*conservative estimate of how many rounds we will need 
 					sum tinc
 					local max=`r(max)'+1
 					*display `max'
 					
 					forvalues j=1/`max'{
 						display `j'
						*then repeat the proccess for the missing days.
						bysort fundno permno (yq): replace costbasis=(costbasis[_n-1]*shares[_n-1] + adjprc*(shares-shares[_n-1]))/shares if add!=1 & shares>=shares[_n-1] & costbasis==.

						bysort fundno permno (yq): replace costbasis=costbasis[_n-1] if add!=1 & shares<shares[_n-1] & costbasis==.

						bysort fundno permno (yq): replace costbasis=costbasis[_n-1] if drop==1 & costbasis==. 						
 					}

 					drop inc tinc

 					****************************
 					*Make another cost basis for add2
					gen costbasis2=adjprc if add2==1

					bysort fundno permno (yq): replace costbasis2=(costbasis2[_n-1]*shares[_n-1] + adjprc*(shares-shares[_n-1]))/shares if add2!=1 & shares>=shares[_n-1]
					
					bysort fundno permno (yq): replace costbasis2=costbasis2[_n-1] if add2!=1 & shares<shares[_n-1]
 					
 					bysort fundno permno (yq): replace costbasis2=costbasis2[_n-1] if drop2==1

 					** first step is to backfill on the zero day
					bysort fundno permno (yq): replace costbasis2=costbasis2[_n-1] if add2!=1 & add==1 & costbasis2==.

					*then repeat the proccess for the missing days.
 					bysort permno bindex2 (yq): gen inc=1 if shares<shares[_n-1] & shares[_n-1]>=shares[_n-2]
 					bysort permno bindex2: egen tinc=total(inc)

 					*conservative estimate of how many rounds we will need -- this will always be an understatement -- so it may run a few extra loops doing nothing
 					sum tinc
 					local max=`r(max)'+1

 					forvalues j=1/`r(max)'{
						bysort fundno permno (yq): replace costbasis2=(costbasis2[_n-1]*shares[_n-1] + adjprc*(shares-shares[_n-1]))/shares if add2!=1 & shares>=shares[_n-1] & costbasis2==.
						
						bysort fundno permno (yq): replace costbasis2=costbasis2[_n-1] if add2!=1 & shares<shares[_n-1] & costbasis2==.
	 					
	 					bysort fundno permno (yq): replace costbasis2=costbasis2[_n-1] if drop2==1 & costbasis2==.
 					}
 					drop inc tinc

					gen egainsdollars=(adjprc-costbasis)*shares
					gen egainsdollars2=(adjprc-costbasis2)*shares
					*what it would be for drops if you sold at the end of the quarter
					replace egainsdollars=(adjprc-costbasis)*shares[_n-1] if drop==1
					replace egainsdollars2=(adjprc-costbasis)*shares[_n-1] if drop2==1

					gen egainspct=(adjprc-costbasis)/costbasis
					gen egainspct2=(adjprc-costbasis2)/costbasis2
					
					egen minyq=min(yq)
					egen maxyq=max(yq)
					sort fundno yq permno
					order fundno yq minyq maxyq permno
					format minyq %tq 
					format maxyq %tq 

					order costbasis* egains* adjprc shares add* drop*

					sort permno yq 
					save "$path\Dropbox\passive_portfolio\breaks12_9_2023\\`no'",replace
					gen totalobs=1
					collapse (sum) totalobs dummy missshares hasis,by(fundno yq)
					merge 1:1 fundno yq using counts
					drop _merge
					save "$path\Dropbox\passive_portfolio\s12changelog\\`no'",replace				
				}
				/*end of >0 after fix loop*/
			}
			/*end of >0 loop*/
		}
		/*end of qui loop*/
	}
	/*end of fundno loop*/
}
/*end of g loop*/
