*global path="D:"
global path="C:\Users\mcsam"
cd "$path\Dropbox\passive_portfolio\data"

****************************************************
*Benchmark and active share data
****************************************************

*From the Active Share website: https://activeshare.nd.edu/data/
import delimited "$path\Downloads\TR Active Share - 1979m6 to 2019m12 - Generated 4 May 2022\TR Active Share - 1979m6 to 2019m12 - Generated 4 May 2022.csv", clear 
keep fundno ym as_r1-as_s6v total_assets wficn
split ym,p("m")
gen year=real(ym1)
gen month=real(ym2)
drop ym
gen ym=ym(year,month)
drop year month
format ym %tm
save temp,replace

use temp,clear
foreach v of varlist as_r1-as_s6v{
	replace `v'=1 if `v'==.
}

/*Take the benchmark closest to each manager's portfolio*/
gen min=as_r1
gen bench="r1"
foreach v of varlist as_r1g-as_s6v{
	local bench=subinstr("`v'","as_","",.)
	*display "`bench'"
	replace bench="`bench'" if `v'<min
	replace min=`v' if `v'<min

}
keep fundno total_assets ym min wficn bench
drop if wficn==.
replace bench=upper(bench)
save mins,replace

** need to convert both of these to quarterly 
/*load data on benchmark returns*/
use totalreturndata3,clear
keep if tr!=.
count
save tr,replace


/*load non-total return index data as an additional check*/
use irets,clear
gen d=dofm(ym)
gen yq=yq(year(d),quarter(d))
format yq %tq
bysort index yq (d): keep if _n==_N
gen r=(close-close[_n-1])/close[_n-1]
drop if r==.
keep index yq r
rename index bench
merge 1:1 bench yq using tr
drop _merge
save benchrets,replace

use benchrets,clear
egen g=group(bench)
xtset g yq
gen fr=F.r
gen ftr=F.tr
save benchrets2,replace
use mins,clear
gen d=dofm(ym)
gen yq=yq(year(d),quarter(d))
format yq %tq
bysort fundno yq (d): keep if _n==_N
merge m:1 bench yq using benchrets2
drop if _merge==2
drop _merge d
save minsb,replace

*future benchmark returns
use minsb,clear
keep fundno yq tr ftr bench
save benchmark_returns,replace

****************************************************
*CRSP data
****************************************************

*CRSP Mutual fund summary data: Load data on CRSP objective coes
use obj_codes,clear
gen year=year(caldt)
bysort crsp_fundno year (caldt): keep if _n==_N
keep crsp_fundno year crsp_obj_cd
save objcodes,replace

*CRSP index data: Create quarterly market returns
use "C:\Users\mcsam\Dropbox\mainwrds\crsp\index_returns.dta",clear
rename *,lower
rename caldt date
gen ym=ym(year(date),month(date))
format ym %tm
gen yq=yq(year(date),quarter(date))
format yq %tq
bysort yq (ym): gen cret=(1+vwretd)*(1+vwretd[_n-1])*(1+vwretd[_n-2])-1
drop if cret==.
keep yq cret
rename cret cret_mkt
save tmmkt,replace

**CRSP Mutual fund summary data: Load annual fund summary data to identify when the fund was first offered, 
use annual_summary,clear
keep crsp_fundno first_offer_dt
drop if first_offer_dt==.
duplicates drop
save first_offer_dates,replace 

use annual_summary,clear
keep if fund_name==""
gen year=year(caldt)
keep crsp_fundno year
duplicates drop 
save name_missing_years,replace

***CRSP Mutual fund summary data: Load data on quarterly SEC turnover
use "turnover.dta",clear
gen yq=yq(year(caldt),quarter(caldt))
format yq %tq
keep crsp_fundno turn_ratio yq
drop if turn_ratio==.
duplicates tag crsp_fundno yq,gen(tag)
drop if tag>0
drop tag
xtset crsp_fundno yq
gen lturn=L.turn_ratio
save tmturn,replace

***CRSP Mutual fund summary data: Load data on annual SEC turnover
use annual_summary,clear
gen year=year(caldt)
drop if turn_ratio==.
bysort crsp_fundno year (caldt): keep if _n==_N
keep crsp_fundno turn_ratio year
rename turn_ratio annturn
duplicates drop
*need to add lag here
xtset crsp_fundno year
gen lannturn=L.annturn
save annualturn,replace

**CRSP Mutual fund summary data: load annual summary data to fill in missing fees sometimes present in the quarterly data
use annual_summary,clear
drop if exp_ratio==.
gen year=year(caldt)
bysort crsp_fundno year (caldt): keep if _n==_N
keep crsp_fundno year exp_ratio
rename exp_ratio annexp
save tmannexp,replace

**CRSP Mutual fund summary data: load quarterly fee data
*note that annexp will be missing for quarters after last year end but before end of fund history
use fees,clear
gen year=year(caldt)
gen yq=yq(year(caldt),quarter(caldt))
format yq %tq
drop if exp_ratio==.
bysort crsp_fundno yq (summary_period2): keep if _n==_N
keep crsp_fundno yq exp_ratio
save cleaned_fees,replace

*From FRED: load CPI data
use "C:\Users\mcsam\Dropbox\EarningsDayVol\ms\data\cpi",clear
gen d=dofm(ym)
gen yq=yq(year(d),quarter(d))
bysort yq (d): keep if _n==_N
keep cpi yq
format yq %tq
*normalize to end of 2015 following Pastor paper
replace cpiaucsl=cpiaucsl/237.761
save tmcpi,replace

**CRSP Mutual fund returns data: Load monthly returns
use all_rets,clear
rename mret ret
foreach k in `c(alpha)' {
	replace ret=. if ret==.`k'
}
gen yq=yq(year(caldt),quarter(caldt))
gen ym=ym(year(caldt),month(caldt))
gen year=year(caldt)
format yq %tq
format ym %tm
drop if crsp_fundno==. 
replace ret=0 if ret==.
drop mnav

rename crsp_fundno permno 
bysort permno yq (ym): gen index=_n
bysort permno yq (ym): gen obs=_N
gen stna=mtna if index==1
gen etna=mtna if index==obs
bysort permno yq: egen s_tna=min(stna)
bysort permno yq: egen e_tna=min(etna)
drop stna etna
*compound to quarterly returns
bysort permno yq (ym): gen cret=1+ret if _n==1
bysort permno yq (ym): replace cret=cret[_n-1]*(1+ret) if _n>1
replace cret = cret-1
keep if index==obs
keep if obs==3
*e_tna is ending TNA
keep permno yq obs s_tna e_tna cret year caldt
rename permno crsp_fundno
xtset crsp_fundno yq
gen ltna=L.e_tna
gen flow=e_tna-ltna*(1+cret)

*quarterly turnover and fees
merge m:1 crsp_fundno yq using tmturn
drop if _merge==2
drop _merge
merge m:1 crsp_fundno yq using cleaned_fees
drop if _merge==2
drop _merge
*counts of daily return observations past 6 months -- used in the Petajisto (2013 paper) -- although we do not apply this filter
merge m:1 crsp_fundno yq using t6m
drop if _merge==2
drop _merge

*annual turnover and fees
merge m:1 crsp_fundno year using annualturn
drop if _merge==2
drop _merge
merge m:1 crsp_fundno year using tmannexp
drop if _merge==2
drop _merge

*data for filters on incubation bias
merge m:1 crsp_fundno using first_offer_dates
drop if _merge==2
drop _merge

gen beforefirst=1 if caldt<first_offer_dt
replace beforefirst=0 if beforefirst==.

merge m:1 crsp_fundno year using name_missing_years
gen missname=1 if _merge==3
drop if _merge==2
drop _merge
replace missname=0 if missname==.

*data for filters on real fund size
merge m:1 yq using tmcpi
drop if _merge==2
drop _merge
gen scaletna=e_tna*(1/cpi)
gen toosmall=1 if scaletna<15
replace toosmall=0 if toosmall==.

merge m:1 crsp_fundno year using objcodes
drop if _merge==2
drop _merge

save crsp_ret_clean,replace

*MF Links data: mapping from CRSP fundno to WFICN
use "$path\Dropbox\passive_portfolio\data\CRSP_FUNDNO-WFICN.dta",clear 
duplicates tag crsp_fundno,gen(tag)
drop if tag>0
drop tag
drop if wficn==.
keep crsp_fundno wficn
save tmwficn,replace

*This is return at the share class level -- need to aggregate to the fund family level to merge with S12
use crsp_ret_clean,clear
merge m:1 crsp_fundno using tmwficn
keep if _merge==3
drop _merge
rename flow crsp_fund_level_flow
drop if ltna==. | e_tna==.

*Take value weighted averages -- note that not all share classes are going to have non-missing values (except for returns b/c of the way that data was constructed) so to be precise, need to construct a different weighting scheme for each variable
bysort wficn yq: egen ttna=total(ltna)
gen wt=ltna/ttna
gen vw_ret=wt*cret

bysort wficn yq: egen ttna2=total(ltna) if turn_ratio!=.
gen wt2=ltna/ttna2 if turn_ratio!=.
gen vw_turn=turn_ratio*wt2

bysort wficn yq: egen ttna3=total(ltna) if exp_ratio!=.
gen wt3=ltna/ttna3 if exp_ratio!=.
gen vwexp_ratio=exp_ratio*wt3

bysort wficn yq: egen ttna4=total(ltna) if annexp!=.
gen wt4=ltna/ttna4 if annexp!=.
gen vwannexp=annexp*wt4

bysort wficn yq: egen ttna5=total(ltna) if annturn!=.
gen wt5=ltna/ttna5 if annturn!=.
gen vwannturn=annturn*wt5

*adding lagged turnover
bysort wficn yq: egen ttna6=total(ltna) if lannturn!=.
gen wt6=ltna/ttna6 if lannturn!=.
gen vwlannturn=lannturn*wt6

bysort wficn yq: egen ttna7=total(ltna) if lturn!=.
gen wt7=ltna/ttna7 if lturn!=.
gen vwlturn=lturn*wt7

foreach v of varlist toosmall missname beforefirst{
	gen min`v'=`v'
	gen max`v'=`v'
}

** keep only the objective code of the largest class
bysort wficn yq (ltna): gen objcode=crsp_obj_cd[_N]

collapse (min) min* (max) max* (sum) vw_ret wt wt2 wt3 wt4 wt5 wt6 wt7 vw_turn ltna e_tna vwexp_ratio vwannexp vwannturn vwlturn vwlannturn ///
	scaletna,by(wficn yq objcode)

*drop if no observations with non-mising returns
drop if wt==0
*set to missing of none of the share classes had non-missing values for each of these variables
replace vw_turn=. if wt2==0
replace vwexp_ratio=. if wt3==0
replace vwannexp=. if wt4==0
replace vwannturn=. if wt5==0
replace vwlturn=. if wt7==0
replace vwlannturn=. if wt6==0

*Going to size at the fund-family level, rather than share class level
drop *toosmall*
gen toosmall=1 if scaletna<=15
replace toosmall=0 if toosmall==.
gen flow=e_tna-ltna*(1+vw_ret)
drop wt wt2 wt3 wt4 wt5 wt6 wt7
save wficn_ret_clean,replace

*MF Links: get list of funds that can be mapped from S12 to WFICN
use "$path\Dropbox\passive_portfolio\data\FUNDNO-WFICN.dta" ,clear
keep if wficn!=.
keep fundno
duplicates drop
save mappedlist,replace

*MF Links: Filter out stale data
use "$path\Dropbox\passive_portfolio\data\FUNDNO-WFICN.dta" ,clear
keep fundno fdate rdate prdate
drop if fundno==.
gen yq=yq(year(fdate),quarter(fdate))
xtset fundno yq
format yq %tq
*Can't just use equals sign -- sometimes rdate walks backward -- so need the less than or equals to sign 
gen stale=1 if rdate<=L.rdate
gen staledrop=1 if stale==1 | L.stale==1

*S12 re-uses fundnos after a year -- documentation says that if a year has passed with no new rdate, safe to assume it's a new fund
bysort fundno (fdate): gen newfund=1 if yq(year(rdate),quarter(rdate))-yq(year(rdate[_n-1]),quarter(rdate[_n-1]))>4 & rdate!=. & rdate[_n-1]!=.
xtset fundno yq
format yq %tq
gen newfunddrop=1 if newfund==1 | F.newfund==1
save tmstaledrop,replace

use mqall,clear
xtset fundno yq
drop if ct==.
*enough holdings filter -- now superseeded by enough non-zero holdings changes filter
gen he=1 if ct>=10 & L.ct>=10
save he,replace 


local index=1
*MF links: start by counting the full number of observations in the FUNDNO WFICN dataset
use "$path\Dropbox\passive_portfolio\data\FUNDNO-WFICN.dta" ,clear
count
local oc`index'=`r(N)'
local index=`index'+1

** Restrict to the set of observations that we have hope of matching -- non-missing S12 fundno + non-duplicate WFICN
drop if fundno==.	
gen yq=yq(year(fdate),quarter(fdate))
drop if wficn==.
duplicates tag wficn yq,gen(tag)
drop if tag>0
drop tag
count
local oc`index'=`r(N)'
local index=`index'+1

merge 1:1 wficn yq using wficn_ret_clean
keep if _merge==3
drop _merge
*non-missing returns in CRSP + flows + lagged tna -- the essential data we need for fund-quarter-level analysis
count
local oc`index'=`r(N)'
local index=`index'+1

replace assets=assets/100
merge m:1 fundno yq using mqall
drop if _merge==2
drop _merge

keep wficn fdate fundno yq minmissname minbeforefirst maxmissname maxbeforefirst vw_ret vw_turn ltna e_tna vwexp_ratio vwannexp vwannturn scaletna toosmall flow fracmatched dheld vwlturn vwlannturn objcode 

/*calculate lagged/forward returns, flows, etc. BEFORE other filters*/
merge m:1 yq using tmmkt
drop if _merge==2
drop _merge
foreach v of varlist vw_ret{
	gen `v'madj=`v'-cret_mkt
}
*compute next period returns
xtset fundno yq
gen fvw_ret=F.vw_ret 
gen fvw_retmadj=F.vw_retmadj
gen flowp=flow/ltna
forvalues j=1/4{
	gen l`j'flowp=L`j'.flowp
}

*information on stale data and # holdings
merge m:1 fundno yq using tmstaledrop
drop if _merge==2
drop _merge
merge m:1 fundno yq using he
drop if _merge==2
drop _merge

*matched at least 2/3rds of dollars
gen frac_dollars=(dheld/1000000)/e_tna
gen med=1 if frac_dollars>0.67 & frac_dollars!=.
replace med=0 if med==.

keep if med==1 & frac_dollars!=.
count
local oc`index'=`r(N)'
local index=`index'+1

*matched 90% of holdings
gen matched_enough=1 if fracmatched>=0.9 & fracmatched!=.
replace matched_enough=0 if matched_enough==.

keep if matched_enough==1 & fracmatched!=.
count
local oc`index'=`r(N)'
local index=`index'+1

*Drop funds with less than 15m real aum
drop if toosmall==1
count
local oc`index'=`r(N)'
local index=`index'+1

*Drop incubation bias
drop if minmissname==1
drop if minbeforefirst==1 
count
local oc`index'=`r(N)'
local index=`index'+1

*Drop if missing SEC turnover
drop if vwlannturn==.
count
local oc`index'=`r(N)'
local index=`index'+1

*Drop if missing expense ratio
gen expfinal=vwexp_ratio
replace expfinal=vwannexp if expfinal==.
drop if expfinal==.
count
local oc`index'=`r(N)'
local index=`index'+1

*get rid of stale holdings-related quarters
drop if staledrop==1
count
local oc`index'=`r(N)'
local index=`index'+1

keep wficn fdate fundno yq vw_ret vw_turn ltna e_tna vwexp_ratio vwannexp vwannturn scaletna flow* l*flow* fracmatched frac_dollars expfinal stale vwlturn vwlannturn ///
	fvw* *madj* objcode
compress
codebook fundno
save s12_ret_9_2023,replace

*get number of non-zero holdings changes 
use r2_all,clear
keep fundno yq nzobsvw3 betavw3 r2vw3
*first and last quarters
bysort fundno: egen minyq=min(yq)
bysort fundno: egen maxyq=max(yq)
save suminfo,replace

use s12_ret_9_2023,clear
merge m:1 fundno yq using mapp_2_2023
drop if _merge==2
drop _merge
merge 1:1 fundno yq using suminfo
drop if _merge==2
drop _merge

*Require 10 holdings in quarter t and t-1 which were not added, dropped, acquired, acquirees and which had non-zero changes (last part is to further remove stale holdings)
keep if nzobsvw3>=10 & nzobsvw3!=.
count
local oc`index'=`r(N)'
local index=`index'+1

*need to apply the filter for first and last AFTER we take all leads/lags of the variables of interest otherwise we will lose observations for no reason
*redundant given nzobs filter above
/*
drop if yq<=minyq | yq>=maxyq
count
local oc`index'=`r(N)'
local index=`index'+1
*/

*next quarter fund-level data
merge 1:1 fundno yq using sharealphaaddsnew
drop if _merge==2
drop _merge
drop wt_fix _1facb_mkt  _3facb_mkt _3facb_smb _3facb_hml  _4facb_mkt _4facb_smb _4facb_hml _4facb_umd  g20
rename _1facalpha next1alpha
rename _3facalpha next3alpha
rename _4facalpha nextalpha
rename qret nextvwret
rename dl nextdl

*current quarter fund-level data
merge 1:1 fundno yq using lsharealphaaddsnew
drop if _merge==2
drop _merge
drop wt_fix _1facb_mkt  _3facb_mkt _3facb_smb _3facb_hml  _4facb_mkt _4facb_smb _4facb_hml _4facb_umd  g20
rename _1facalpha curr1alpha
rename _3facalpha curr3alpha
rename _4facalpha curralpha
rename qret currvwret
rename dl currdl

foreach name in "ct" "miss" "adollars" "ddollars" "residdollars" "aresiddollars" "tdollars"{
	capture drop `v'
}
*drop if missing next quarter reutrns or alphas
drop if nextalpha==. | fvw_ret==. | fvw_retmadj==.
count
local oc`index'=`r(N)'
local index=`index'+1

gen d=dofq(yq)
gen year=year(d)
gen month=month(d)
replace month=month+2
gen ym=ym(year,month)
format ym %tm
*merge in active share data
*merge m:1 fundno ym using minsb3
merge m:1 fundno ym using minsb
drop if _merge==2
drop _merge
rename min actshare
*Drop if missing active share
drop if actshare==.
count
local oc`index'=`r(N)'
local index=`index'+1

*apply win, b/c these can be arbitrarily large/small
winsor2 vw_ret fvw_ret vw_retmadj fvw_retmadj,  cuts(1 99)  replace by(yq)
winsor2 vw_turn vwannturn vwlturn vwlannturn,cuts(1 99) replace by(yq)
winsor2 nextalpha curralpha,cuts(1 99) replace by(yq)
winsor2 *flowp*, cuts(1 99) replace

rename vwexp_ratio expratio
bysort fundno (yq): replace expratio=expratio[_n-1] if expratio==.
replace expratio=expratio/4
foreach v of varlist vw_ret fvw_ret{
	gen gross`v'=`v'+expratio
}
foreach v of varlist vw_ret fvw_ret *madj* *gross*{
	gen ann`v'=(1+`v')^4-1
	replace ann`v'=`v'*100
}
winsor2 ann*,cuts(1 99) replace

*if ever passive flag
bysort fundno: egen maxpass=max(passive)
drop passive
rename maxpass passive

save all_fund_yq_data,replace

use all_fund_yq_data,clear

*drop if missing benchmark adj returns
drop if tr==. | ftr==.
count
local oc`index'=`r(N)'
local index=`index'+1

*drop passive funds
drop if passive==1
count
local oc`index'=`r(N)'
local index=`index'+1

*drop singeltons
capture drop obs
bysort yq: gen obs=_N
drop if obs==1
drop obs
bysort fundno: gen obs=_N
drop if obs==1
drop obs
count
local oc`index'=`r(N)'
local index=`index'+1

save xsdata_11_29_2023,replace
save "C:\Users\mcsam\Dropbox\passive_portfolio\replication_data\active_fund_quarters",replace

keep fundno
duplicates drop
count
local oc`index'=`r(N)'
local index=`index'+1


** Data for placebo tests on passive funds
use all_fund_yq_data,clear
keep if passive==1

*drop if missing benchmark adj returns
drop if tr==. | ftr==.
count
local oc`index'=`r(N)'
local index=`index'+1

capture drop obs
bysort yq: gen obs=_N
drop if obs==1
drop obs
bysort fundno: gen obs=_N
drop if obs==1
drop obs
save placebo_11_29_2023,replace
save "C:\Users\mcsam\Dropbox\passive_portfolio\replication_data\passive_fund_quarters",replace

keep fundno
*check how many passive funds, should be in the ballpark of ~1000
duplicates drop 
count

clear
set obs `index'
gen obscount=.
local stop=`index'-1
forvalues j=1/`stop'{
	replace obscount = `oc`j'' if _n==`j' 
}


global path="D:"
*global path="C:\Users\mcsam"
cd "$path\Dropbox\passive_portfolio\data"

use all_fund_yq_data,clear
keep fundno yq objcode
egen g=group(objcode)
bysort fundno: egen mg=min(g)
bysort fundno: egen mg2=max(g)
gen change=1 if mg!=mg2
replace change=0 if change==.
drop g mg mg2
merge m:1 fundno using ncs
drop if _merge==2
drop _merge
save "$path\Dropbox\passive_portfolio\replication_data\objcodes",replace

