cd /Users/jshim2/Dropbox/projects/passive_portfolio/replication_data


*******************************************************************
* Split on Embedded Gains and Holding Period
*******************************************************************
use active_sfq_regdata, clear

merge 1:1 fundno permno yq using holdingperiods
keep if _merge == 3
drop _merge

merge 1:1 permno fundno yq using egains
keep if _merge == 3
drop _merge

preserve
collapse (median) holdingperiod2, by(fundno yq)
rename holdingperiod2 medianholdingperiod
sum medianholdingperiod, d
save temp_medianholding_fundyq, replace
restore

merge m:1 fundno yq using temp_medianholding_fundyq
drop _merge


* Table 10, embedded gain & long holding period
preserve
keep if egainspct2 > 0
keep if holdingperiod2 > medianholdingperiod

capture drop obs
bysort fundno yq: gen obs=_N
drop if obs==1
drop obs

gen wt_cf = shares * abs(adjprc)
replace wt_cf = lsharesvar * abs(adjprc) if dropvar == 1
bysort fundno yq: egen wttot = total(wt_cf)
replace wtfund_cf = wt_cf / wttot
drop wt_cf wttot

local a=1
foreach v of varlist f1_4facalphabpsq f1_qretbenchadjbps {
	reghdfe `v' rebalinadja rebalinadjd rebaloutd ///
				actshare vwlannturn [aw=wtfund_cf], ///
	 		 noa vce(cluster yq permno fundno)
	if `a' == 1 {
		outreg2 using _regs/sfqreg_active_2way_posgain_hhold, replace bdec(3)
		local a=2
	}
	else{
		outreg2 using _regs/sfqreg_active_2way_posgain_hhold, append bdec(3)
	}
	reghdfe `v' rebalinadja rebalinadjd rebaloutd ///
				actshare vwlannturn [aw=wtfund_cf], ///
	 		 	absorb(fundno yq) vce(cluster yq permno fundno)
	outreg2 using _regs/sfqreg_active_2way_posgain_hhold, append bdec(3)
	reghdfe `v' rebalinadja rebalinadjd  ///
				rebaloutd [aw=wtfund_cf], ///
	 		 	absorb(fundno#yq) vce(cluster yq permno fundno)
	outreg2 using _regs/sfqreg_active_2way_posgain_hhold, append bdec(3)
}
restore


* Table 10, embedded gain & short holding period
preserve
keep if egainspct2 > 0
keep if holdingperiod2 <= medianholdingperiod

capture drop obs
bysort fundno yq: gen obs=_N
drop if obs==1
drop obs

gen wt_cf = shares * abs(adjprc)
replace wt_cf = lsharesvar * abs(adjprc) if dropvar == 1
bysort fundno yq: egen wttot = total(wt_cf)
replace wtfund_cf = wt_cf / wttot
drop wt_cf wttot

local a=1
foreach v of varlist f1_4facalphabpsq f1_qretbenchadjbps {
	reghdfe `v' rebalinadja rebalinadjd rebaloutd ///
				actshare vwlannturn [aw=wtfund_cf], ///
	 		 noa vce(cluster yq permno fundno)
	if `a' == 1 {
		outreg2 using _regs/sfqreg_active_2way_posgain_lhold, replace bdec(3)
		local a=2
	}
	else{
		outreg2 using _regs/sfqreg_active_2way_posgain_lhold, append bdec(3)
	}
	reghdfe `v' rebalinadja rebalinadjd rebaloutd ///
				actshare vwlannturn [aw=wtfund_cf], ///
	 		 	absorb(fundno yq) vce(cluster yq permno fundno)
	outreg2 using _regs/sfqreg_active_2way_posgain_lhold, append bdec(3)
	reghdfe `v' rebalinadja rebalinadjd  ///
				rebaloutd [aw=wtfund_cf], ///
	 		 	absorb(fundno#yq) vce(cluster yq permno fundno)
	outreg2 using _regs/sfqreg_active_2way_posgain_lhold, append bdec(3)
}
restore


* Table 10, embedded loss & short holding period
preserve
keep if egainspct2 < 0
keep if holdingperiod2 <= medianholdingperiod

capture drop obs
bysort fundno yq: gen obs=_N
drop if obs==1
drop obs

gen wt_cf = shares * abs(adjprc)
replace wt_cf = lsharesvar * abs(adjprc) if dropvar == 1
bysort fundno yq: egen wttot = total(wt_cf)
replace wtfund_cf = wt_cf / wttot
drop wt_cf wttot

local a=1
foreach v of varlist f1_4facalphabpsq f1_qretbenchadjbps {
	reghdfe `v' rebalinadja rebalinadjd rebaloutd ///
				actshare vwlannturn [aw=wtfund_cf], ///
	 		 noa vce(cluster yq permno fundno)
	if `a' == 1 {
		outreg2 using _regs/sfqreg_active_2way_neggain_lhold, replace bdec(3)
		local a=2
	}
	else{
		outreg2 using _regs/sfqreg_active_2way_neggain_lhold, append bdec(3)
	}
	reghdfe `v' rebalinadja rebalinadjd rebaloutd ///
				actshare vwlannturn [aw=wtfund_cf], ///
	 		 	absorb(fundno yq) vce(cluster yq permno fundno)
	outreg2 using _regs/sfqreg_active_2way_neggain_lhold, append bdec(3)
	reghdfe `v' rebalinadja rebalinadjd  ///
				rebaloutd [aw=wtfund_cf], ///
	 		 	absorb(fundno#yq) vce(cluster yq permno fundno)
	outreg2 using _regs/sfqreg_active_2way_neggain_lhold, append bdec(3)
}
restore


* Table 10, embedded gain & long holding period
preserve
keep if egainspct2 < 0
keep if holdingperiod2 > medianholdingperiod

capture drop obs
bysort fundno yq: gen obs=_N
drop if obs==1
drop obs

gen wt_cf = shares * abs(adjprc)
replace wt_cf = lsharesvar * abs(adjprc) if dropvar == 1
bysort fundno yq: egen wttot = total(wt_cf)
replace wtfund_cf = wt_cf / wttot
drop wt_cf wttot

local a=1
foreach v of varlist f1_4facalphabpsq f1_qretbenchadjbps {
	reghdfe `v' rebalinadja rebalinadjd rebaloutd ///
				actshare vwlannturn [aw=wtfund_cf], ///
	 		 noa vce(cluster yq permno fundno)
	if `a' == 1 {
		outreg2 using _regs/sfqreg_active_2way_neggain_hhold, replace bdec(3)
		local a=2
	}
	else{
		outreg2 using _regs/sfqreg_active_2way_neggain_hhold, append bdec(3)
	}
	reghdfe `v' rebalinadja rebalinadjd rebaloutd ///
				actshare vwlannturn [aw=wtfund_cf], ///
	 		 	absorb(fundno yq) vce(cluster yq permno fundno)
	outreg2 using _regs/sfqreg_active_2way_neggain_hhold, append bdec(3)
	reghdfe `v' rebalinadja rebalinadjd  ///
				rebaloutd [aw=wtfund_cf], ///
	 		 	absorb(fundno#yq) vce(cluster yq permno fundno)
	outreg2 using _regs/sfqreg_active_2way_neggain_hhold, append bdec(3)
}
restore


*******************************************************************
* Split on Size and Number of Holdings
*******************************************************************
use active_sfq_regdata, clear

preserve
bysort fundno yq: gen numpos = _N
duplicates drop fundno yq numpos, force
keep fundno yq numpos
save temp_numpos, replace

collapse (median) numpos, by(yq)
*tsset yq
*tsline numpos
rename numpos mediannumpos
save temp_mediannumpos, replace
restore

preserve
collapse (median) e_tna, by(yq)
rename e_tna mediantna
save temp_mediantna, replace
restore


use active_sfq_regdata, clear

merge m:1 fundno yq using temp_numpos
drop _merge
merge m:1 yq using temp_mediannumpos
drop _merge
merge m:1 yq using temp_mediantna
drop _merge


* Table 11, large fund size & high num positions
preserve
keep if e_tna > mediantna
keep if numpos > mediannumpos

capture drop obs
bysort fundno yq: gen obs=_N
drop if obs==1
drop obs

gen wt_cf = shares * abs(adjprc)
replace wt_cf = lsharesvar * abs(adjprc) if dropvar == 1
bysort fundno yq: egen wttot = total(wt_cf)
replace wtfund_cf = wt_cf / wttot
drop wt_cf wttot

local a=1
foreach v of varlist f1_4facalphabpsq f1_qretbenchadjbps {
	reghdfe `v' rebalinadja rebalinadjd rebalouta rebaloutd ///
				actshare vwlannturn [aw=wtfund_cf], ///
	 		 noa vce(cluster yq permno fundno)
	if `a' == 1 {
		outreg2 using _regs/sfqreg_active_2way_htna_hnum, replace bdec(3)
		local a=2
	}
	else{
		outreg2 using _regs/sfqreg_active_2way_htna_hnum, append bdec(3)
	}
	reghdfe `v' rebalinadja rebalinadjd rebalouta rebaloutd ///
				actshare vwlannturn [aw=wtfund_cf], ///
	 		 	absorb(fundno yq) vce(cluster yq permno fundno)
	outreg2 using _regs/sfqreg_active_2way_htna_hnum, append bdec(3)
	reghdfe `v' rebalinadja rebalinadjd  ///
				rebalouta rebaloutd [aw=wtfund_cf], ///
	 		 	absorb(fundno#yq) vce(cluster yq permno fundno)
	outreg2 using _regs/sfqreg_active_2way_htna_hnum, append bdec(3)
}
restore


* Table 11, large fund size & low num positions
preserve
keep if e_tna > mediantna
keep if numpos <= mediannumpos

capture drop obs
bysort fundno yq: gen obs=_N
drop if obs==1
drop obs

gen wt_cf = shares * abs(adjprc)
replace wt_cf = lsharesvar * abs(adjprc) if dropvar == 1
bysort fundno yq: egen wttot = total(wt_cf)
replace wtfund_cf = wt_cf / wttot
drop wt_cf wttot

local a=1
foreach v of varlist f1_4facalphabpsq f1_qretbenchadjbps {
	reghdfe `v' rebalinadja rebalinadjd rebalouta rebaloutd ///
				actshare vwlannturn [aw=wtfund_cf], ///
	 		 noa vce(cluster yq permno fundno)
	if `a' == 1 {
		outreg2 using _regs/sfqreg_active_2way_htna_lnum, replace bdec(3)
		local a=2
	}
	else{
		outreg2 using _regs/sfqreg_active_2way_htna_lnum, append bdec(3)
	}
	reghdfe `v' rebalinadja rebalinadjd rebalouta rebaloutd ///
				actshare vwlannturn [aw=wtfund_cf], ///
	 		 	absorb(fundno yq) vce(cluster yq permno fundno)
	outreg2 using _regs/sfqreg_active_2way_htna_lnum, append bdec(3)
	reghdfe `v' rebalinadja rebalinadjd  ///
				rebalouta rebaloutd [aw=wtfund_cf], ///
	 		 	absorb(fundno#yq) vce(cluster yq permno fundno)
	outreg2 using _regs/sfqreg_active_2way_htna_lnum, append bdec(3)
}
restore


* Table 11, small fund size & high num positions
preserve
keep if e_tna <= mediantna
keep if numpos > mediannumpos

capture drop obs
bysort fundno yq: gen obs=_N
drop if obs==1
drop obs

gen wt_cf = shares * abs(adjprc)
replace wt_cf = lsharesvar * abs(adjprc) if dropvar == 1
bysort fundno yq: egen wttot = total(wt_cf)
replace wtfund_cf = wt_cf / wttot
drop wt_cf wttot

local a=1
foreach v of varlist f1_4facalphabpsq f1_qretbenchadjbps {
	reghdfe `v' rebalinadja rebalinadjd rebalouta rebaloutd ///
				actshare vwlannturn [aw=wtfund_cf], ///
	 		 noa vce(cluster yq permno fundno)
	if `a' == 1 {
		outreg2 using _regs/sfqreg_active_2way_ltna_hnum, replace bdec(3)
		local a=2
	}
	else{
		outreg2 using _regs/sfqreg_active_2way_ltna_hnum, append bdec(3)
	}
	reghdfe `v' rebalinadja rebalinadjd rebalouta rebaloutd ///
				actshare vwlannturn [aw=wtfund_cf], ///
	 		 	absorb(fundno yq) vce(cluster yq permno fundno)
	outreg2 using _regs/sfqreg_active_2way_ltna_hnum, append bdec(3)
	reghdfe `v' rebalinadja rebalinadjd  ///
				rebalouta rebaloutd [aw=wtfund_cf], ///
	 		 	absorb(fundno#yq) vce(cluster yq permno fundno)
	outreg2 using _regs/sfqreg_active_2way_ltna_hnum, append bdec(3)
}
restore


* Table 11, small fund size & low num positions
preserve
keep if e_tna <= mediantna
keep if numpos <= mediannumpos

capture drop obs
bysort fundno yq: gen obs=_N
drop if obs==1
drop obs

gen wt_cf = shares * abs(adjprc)
replace wt_cf = lsharesvar * abs(adjprc) if dropvar == 1
bysort fundno yq: egen wttot = total(wt_cf)
replace wtfund_cf = wt_cf / wttot
drop wt_cf wttot

local a=1
foreach v of varlist f1_4facalphabpsq f1_qretbenchadjbps {
	reghdfe `v' rebalinadja rebalinadjd rebalouta rebaloutd ///
				actshare vwlannturn [aw=wtfund_cf], ///
	 		 noa vce(cluster yq permno fundno)
	if `a' == 1 {
		outreg2 using _regs/sfqreg_active_2way_ltna_lnum, replace bdec(3)
		local a=2
	}
	else{
		outreg2 using _regs/sfqreg_active_2way_ltna_lnum, append bdec(3)
	}
	reghdfe `v' rebalinadja rebalinadjd rebalouta rebaloutd ///
				actshare vwlannturn [aw=wtfund_cf], ///
	 		 	absorb(fundno yq) vce(cluster yq permno fundno)
	outreg2 using _regs/sfqreg_active_2way_ltna_lnum, append bdec(3)
	reghdfe `v' rebalinadja rebalinadjd  ///
				rebalouta rebaloutd [aw=wtfund_cf], ///
	 		 	absorb(fundno#yq) vce(cluster yq permno fundno)
	outreg2 using _regs/sfqreg_active_2way_ltna_lnum, append bdec(3)
}
restore


*******************************************************************
* Split on Stocks with/without Embedded Gains at Position Level
*******************************************************************
use active_sfq_regdata, clear
merge 1:1 permno fundno yq using egains
keep if _merge == 3
drop _merge


* Table 17, with embedded gain
preserve
keep if egainspct2 > 0

capture drop obs
bysort fundno yq: gen obs=_N
drop if obs==1
drop obs

gen wt_cf = shares * abs(adjprc)
replace wt_cf = lsharesvar * abs(adjprc) if dropvar == 1
bysort fundno yq: egen wttot = total(wt_cf)
replace wtfund_cf = wt_cf / wttot
drop wt_cf wttot

local a=1
foreach v of varlist f1_4facalphabpsq f1_qretbenchadjbps {
	reghdfe `v' rebalinadja rebalinadjd rebaloutd ///
				actshare vwlannturn [aw=wtfund_cf], ///
	 		 noa vce(cluster yq permno fundno)
	if `a' == 1 {
		outreg2 using _regs/sfqreg_active_egainspos, replace bdec(3)
		local a=2
	}
	else{
		outreg2 using _regs/sfqreg_active_egainspos, append bdec(3)
	}
	reghdfe `v' rebalinadja rebalinadjd rebaloutd ///
				actshare vwlannturn [aw=wtfund_cf], ///
	 		 	absorb(fundno yq) vce(cluster yq permno fundno)
	outreg2 using _regs/sfqreg_active_egainspos, append bdec(3)
	reghdfe `v' rebalinadja rebalinadjd  ///
				rebaloutd [aw=wtfund_cf], ///
	 		 	absorb(fundno#yq) vce(cluster yq permno fundno)
	outreg2 using _regs/sfqreg_active_egainspos, append bdec(3)
}
restore


* Table 17, with embedded loss
preserve
keep if egainspct2 < 0

capture drop obs
bysort fundno yq: gen obs=_N
drop if obs==1
drop obs

gen wt_cf = shares * abs(adjprc)
replace wt_cf = lsharesvar * abs(adjprc) if dropvar == 1
bysort fundno yq: egen wttot = total(wt_cf)
replace wtfund_cf = wt_cf / wttot
drop wt_cf wttot

local a=1
foreach v of varlist f1_4facalphabpsq f1_qretbenchadjbps {
	reghdfe `v' rebalinadja rebalinadjd rebaloutd ///
				actshare vwlannturn [aw=wtfund_cf], ///
	 		 noa vce(cluster yq permno fundno)
	if `a' == 1 {
		outreg2 using _regs/sfqreg_active_egainsneg, replace bdec(3)
		local a=2
	}
	else{
		outreg2 using _regs/sfqreg_active_egainsneg, append bdec(3)
	}
	reghdfe `v' rebalinadja rebalinadjd rebaloutd ///
				actshare vwlannturn [aw=wtfund_cf], ///
	 		 	absorb(fundno yq) vce(cluster yq permno fundno)
	outreg2 using _regs/sfqreg_active_egainsneg, append bdec(3)
	reghdfe `v' rebalinadja rebalinadjd  ///
				rebaloutd [aw=wtfund_cf], ///
	 		 	absorb(fundno#yq) vce(cluster yq permno fundno)
	outreg2 using _regs/sfqreg_active_egainsneg, append bdec(3)
}
restore


*******************************************************************
* Split on Embedded Gains Relative to Fund Median Gain
*******************************************************************
use active_sfq_regdata, clear
merge 1:1 permno fundno yq using egains
keep if _merge == 3
drop _merge

drop if add2 == 1
bysort fundno yq: egen m = median(egainspct2)
replace egainspct2 = egainspct2 - m
drop m


preserve
keep if egainspct2 > 0

capture drop obs
bysort fundno yq: gen obs=_N
drop if obs==1
drop obs

gen wt_cf = shares * abs(adjprc)
replace wt_cf = lsharesvar * abs(adjprc) if dropvar == 1
bysort fundno yq: egen wttot = total(wt_cf)
replace wtfund_cf = wt_cf / wttot
drop wt_cf wttot

local a=1
foreach v of varlist f1_4facalphabpsq f1_qretbenchadjbps {
	reghdfe `v' rebalinadja rebalinadjd rebaloutd ///
				actshare vwlannturn [aw=wtfund_cf], ///
	 		 noa vce(cluster yq permno fundno)
	if `a' == 1 {
		outreg2 using _regs/sfqreg_active_egainsabovemed, replace bdec(3)
		local a=2
	}
	else{
		outreg2 using _regs/sfqreg_active_egainsabovemed, append bdec(3)
	}
	reghdfe `v' rebalinadja rebalinadjd rebaloutd ///
				actshare vwlannturn [aw=wtfund_cf], ///
	 		 	absorb(fundno yq) vce(cluster yq permno fundno)
	outreg2 using _regs/sfqreg_active_egainsabovemed, append bdec(3)
	reghdfe `v' rebalinadja rebalinadjd  ///
				rebaloutd [aw=wtfund_cf], ///
	 		 	absorb(fundno#yq) vce(cluster yq permno fundno)
	outreg2 using _regs/sfqreg_active_egainsabovemed, append bdec(3)
}
restore


preserve
keep if egainspct2 < 0

capture drop obs
bysort fundno yq: gen obs=_N
drop if obs==1
drop obs

gen wt_cf = shares * abs(adjprc)
replace wt_cf = lsharesvar * abs(adjprc) if dropvar == 1
bysort fundno yq: egen wttot = total(wt_cf)
replace wtfund_cf = wt_cf / wttot
drop wt_cf wttot

local a=1
foreach v of varlist f1_4facalphabpsq f1_qretbenchadjbps {
	reghdfe `v' rebalinadja rebalinadjd rebaloutd ///
				actshare vwlannturn [aw=wtfund_cf], ///
	 		 noa vce(cluster yq permno fundno)
	if `a' == 1 {
		outreg2 using _regs/sfqreg_active_egainsbelowmed, replace bdec(3)
		local a=2
	}
	else{
		outreg2 using _regs/sfqreg_active_egainsbelowmed, append bdec(3)
	}
	reghdfe `v' rebalinadja rebalinadjd rebaloutd ///
				actshare vwlannturn [aw=wtfund_cf], ///
	 		 	absorb(fundno yq) vce(cluster yq permno fundno)
	outreg2 using _regs/sfqreg_active_egainsbelowmed, append bdec(3)
	reghdfe `v' rebalinadja rebalinadjd  ///
				rebaloutd [aw=wtfund_cf], ///
	 		 	absorb(fundno#yq) vce(cluster yq permno fundno)
	outreg2 using _regs/sfqreg_active_egainsbelowmed, append bdec(3)
}
restore


*******************************************************************
* Split on # of Stocks Held at Fund Level
*******************************************************************
use active_sfq_regdata, clear
merge m:1 fundno yq using temp_numpos
drop _merge
merge m:1 yq using temp_mediannumpos
drop _merge


* Table 19, num stocks held above median
preserve 
keep if numpos > mediannumpos
local a=1
foreach v of varlist f1_4facalphabpsq f1_qretbenchadjbps {
	reghdfe `v' rebalinadja rebalinadjd rebalouta rebaloutd ///
				actshare vwlannturn [aw=wtfund_cf], ///
	 		 noa vce(cluster yq permno fundno)
	if `a' == 1 {
		outreg2 using _regs/sfqreg_active_highhold, replace bdec(3)
		local a=2
	}
	else{
		outreg2 using _regs/sfqreg_active_highhold, append bdec(3)
	}
	reghdfe `v' rebalinadja rebalinadjd rebalouta rebaloutd  ///
				actshare vwlannturn [aw=wtfund_cf], ///
	 		 	absorb(fundno yq) vce(cluster yq permno fundno)
	outreg2 using _regs/sfqreg_active_highhold, append bdec(3)
	reghdfe `v' rebalinadja rebalinadjd  ///
				rebalouta rebaloutd [aw=wtfund_cf], ///
	 		 	absorb(fundno#yq) vce(cluster yq permno fundno)
	outreg2 using _regs/sfqreg_active_highhold, append bdec(3)
}
restore

* Table 19, num stocks held at or below median
preserve 
keep if numpos <= mediannumpos
local a=1
foreach v of varlist f1_4facalphabpsq f1_qretbenchadjbps {
	reghdfe `v' rebalinadja rebalinadjd rebalouta rebaloutd ///
				actshare vwlannturn [aw=wtfund_cf], ///
	 		 noa vce(cluster yq permno fundno)
	if `a' == 1 {
		outreg2 using _regs/sfqreg_active_lowhold, replace
		local a=2
	}
	else{
		outreg2 using _regs/sfqreg_active_lowhold, append bdec(3)
	}
	reghdfe `v' rebalinadja rebalinadjd rebalouta rebaloutd ///
				actshare vwlannturn [aw=wtfund_cf], ///
	 		 	absorb(fundno yq) vce(cluster yq permno fundno)
	outreg2 using _regs/sfqreg_active_lowhold, append bdec(3)
	reghdfe `v' rebalinadja rebalinadjd  ///
				rebalouta rebaloutd [aw=wtfund_cf], ///
	 		 	absorb(fundno#yq) vce(cluster yq permno fundno)
	outreg2 using _regs/sfqreg_active_lowhold, append bdec(3)
}
restore


*******************************************************************
* Split on Holding Period at Fund Level Relative to YQ Median
*******************************************************************
use active_sfq_regdata, clear
merge 1:1 fundno permno yq using holdingperiods
keep if _merge == 3
drop _merge

preserve
collapse (mean) holdingperiod2, by(fundno yq)
rename holdingperiod2 meanholdingperiod
save temp_meanholding_fundyq, replace

collapse (median) meanholdingperiod, by(yq)
rename meanholdingperiod medianyqholdingperiod
save temp_medianholding_yq, replace
restore

merge m:1 fundno yq using temp_meanholding_fundyq
drop _merge

merge m:1 yq using temp_medianholding_yq
drop _merge


* Table 21, fund avg holding period greater than YQ median
preserve 
keep if meanholdingperiod > medianyqholdingperiod
local a=1
foreach v of varlist f1_4facalphabpsq f1_qretbenchadjbps {
	reghdfe `v' rebalinadja rebalinadjd rebalouta rebaloutd ///
				actshare vwlannturn [aw=wtfund_cf], ///
	 		 noa vce(cluster yq permno fundno)
	if `a' == 1 {
		outreg2 using _regs/sfqreg_active_longhold, replace
		local a=2
	}
	else{
		outreg2 using _regs/sfqreg_active_longhold, append bdec(3)
	}
	reghdfe `v' rebalinadja rebalinadjd rebalouta rebaloutd ///
				actshare vwlannturn [aw=wtfund_cf], ///
	 		 	absorb(fundno yq) vce(cluster yq permno fundno)
	outreg2 using _regs/sfqreg_active_longhold, append bdec(3)
	reghdfe `v' rebalinadja rebalinadjd  ///
				rebalouta rebaloutd [aw=wtfund_cf], ///
	 		 	absorb(fundno#yq) vce(cluster yq permno fundno)
	outreg2 using _regs/sfqreg_active_longhold, append bdec(3)
}
restore


* Table 21, fund avg holding period at or less than YQ median
preserve 
keep if meanholdingperiod <= medianyqholdingperiod
local a=1
foreach v of varlist f1_4facalphabpsq f1_qretbenchadjbps {
	reghdfe `v' rebalinadja rebalinadjd rebalouta rebaloutd ///
				actshare vwlannturn [aw=wtfund_cf], ///
	 		 noa vce(cluster yq permno fundno)
	if `a' == 1 {
		outreg2 using _regs/sfqreg_active_shorthold, replace
		local a=2
	}
	else{
		outreg2 using _regs/sfqreg_active_shorthold, append bdec(3)
	}
	reghdfe `v' rebalinadja rebalinadjd rebalouta rebaloutd ///
				actshare vwlannturn [aw=wtfund_cf], ///
	 		 	absorb(fundno yq) vce(cluster yq permno fundno)
	outreg2 using _regs/sfqreg_active_shorthold, append bdec(3)
	reghdfe `v' rebalinadja rebalinadjd  ///
				rebalouta rebaloutd [aw=wtfund_cf], ///
	 		 	absorb(fundno#yq) vce(cluster yq permno fundno)
	outreg2 using _regs/sfqreg_active_shorthold, append bdec(3)
}
restore


*******************************************************************
* Split on Holding Period at Stock Level
*******************************************************************
use active_sfq_regdata, clear
merge 1:1 fundno permno yq using holdingperiods
keep if _merge == 3
drop _merge

preserve
collapse (median) holdingperiod2, by(fundno yq)
rename holdingperiod2 medianholdingperiod
sum medianholdingperiod, d
save temp_medianholding_fundyq, replace
restore

merge m:1 fundno yq using temp_medianholding_fundyq
drop _merge


* Table 18, holding period above fund median
preserve 
keep if holdingperiod2 > medianholdingperiod

capture drop obs
bysort fundno yq: gen obs=_N
drop if obs==1
drop obs

gen wt_cf = shares * abs(adjprc)
replace wt_cf = lsharesvar * abs(adjprc) if dropvar == 1
bysort fundno yq: egen wttot = total(wt_cf)
replace wtfund_cf = wt_cf / wttot
drop wt_cf wttot


local a=1
foreach v of varlist f1_4facalphabpsq f1_qretbenchadjbps {
	reghdfe `v' rebalinadja rebalinadjd rebaloutd ///
				actshare vwlannturn [aw=wtfund_cf], ///
	 		 noa vce(cluster yq permno fundno)
	if `a' == 1 {
		outreg2 using _regs/sfqreg_active_stocklvl_longhold, replace
		local a=2
	}
	else{
		outreg2 using _regs/sfqreg_active_stocklvl_longhold, append bdec(3)
	}
	reghdfe `v' rebalinadja rebalinadjd rebaloutd ///
				actshare vwlannturn [aw=wtfund_cf], ///
	 		 	absorb(fundno yq) vce(cluster yq permno fundno)
	outreg2 using _regs/sfqreg_active_stocklvl_longhold, append bdec(3)
	reghdfe `v' rebalinadja rebalinadjd  ///
				rebaloutd [aw=wtfund_cf], ///
	 		 	absorb(fundno#yq) vce(cluster yq permno fundno)
	outreg2 using _regs/sfqreg_active_stocklvl_longhold, append bdec(3)
}
restore


* Table 18, holding period at or below fund median (and greater than 0)
preserve 
keep if holdingperiod2 <= medianholdingperiod
keep if holdingperiod2 > 0

capture drop obs
bysort fundno yq: gen obs=_N
drop if obs==1
drop obs

gen wt_cf = shares * abs(adjprc)
replace wt_cf = lsharesvar * abs(adjprc) if dropvar == 1
bysort fundno yq: egen wttot = total(wt_cf)
replace wtfund_cf = wt_cf / wttot
drop wt_cf wttot


local a=1
foreach v of varlist f1_4facalphabpsq f1_qretbenchadjbps {
	reghdfe `v' rebalinadja rebalinadjd rebaloutd ///
				actshare vwlannturn [aw=wtfund_cf], ///
	 		 noa vce(cluster yq permno fundno)
	if `a' == 1 {
		outreg2 using _regs/sfqreg_active_stocklvl_shorthold, replace
		local a=2
	}
	else{
		outreg2 using _regs/sfqreg_active_stocklvl_shorthold, append bdec(3)
	}
	reghdfe `v' rebalinadja rebalinadjd rebaloutd ///
				actshare vwlannturn [aw=wtfund_cf], ///
	 		 	absorb(fundno yq) vce(cluster yq permno fundno)
	outreg2 using _regs/sfqreg_active_stocklvl_shorthold, append bdec(3)
	reghdfe `v' rebalinadja rebalinadjd  ///
				rebaloutd [aw=wtfund_cf], ///
	 		 	absorb(fundno#yq) vce(cluster yq permno fundno)
	outreg2 using _regs/sfqreg_active_stocklvl_shorthold, append bdec(3)
}
restore



*******************************************************************
* Split on Fund Size relative to Median
*******************************************************************
use active_sfq_regdata, clear

merge m:1 yq using temp_mediantna
drop _merge

* Table 20, fund size above median
preserve
keep if e_tna > mediantna

capture drop obs
bysort fundno yq: gen obs=_N
drop if obs==1
drop obs

gen wt_cf = shares * abs(adjprc)
replace wt_cf = lsharesvar * abs(adjprc) if dropvar == 1
bysort fundno yq: egen wttot = total(wt_cf)
replace wtfund_cf = wt_cf / wttot
drop wt_cf wttot

local a=1
foreach v of varlist f1_4facalphabpsq f1_qretbenchadjbps {
	reghdfe `v' rebalinadja rebalinadjd rebalouta rebaloutd ///
				actshare vwlannturn [aw=wtfund_cf], ///
	 		 noa vce(cluster yq permno fundno)
	if `a' == 1 {
		outreg2 using _regs/sfqreg_active_hightna, replace
		local a=2
	}
	else{
		outreg2 using _regs/sfqreg_active_hightna, append bdec(3)
	}
	reghdfe `v' rebalinadja rebalinadjd rebalouta rebaloutd ///
				actshare vwlannturn [aw=wtfund_cf], ///
	 		 	absorb(fundno yq) vce(cluster yq permno fundno)
	outreg2 using _regs/sfqreg_active_hightna, append bdec(3)
	reghdfe `v' rebalinadja rebalinadjd  ///
				rebalouta rebaloutd [aw=wtfund_cf], ///
	 		 	absorb(fundno#yq) vce(cluster yq permno fundno)
	outreg2 using _regs/sfqreg_active_hightna, append bdec(3)
}
restore


* Table 20, fund size at or below median
preserve
keep if e_tna <= mediantna

capture drop obs
bysort fundno yq: gen obs=_N
drop if obs==1
drop obs

gen wt_cf = shares * abs(adjprc)
replace wt_cf = lsharesvar * abs(adjprc) if dropvar == 1
bysort fundno yq: egen wttot = total(wt_cf)
replace wtfund_cf = wt_cf / wttot
drop wt_cf wttot

local a=1
foreach v of varlist f1_4facalphabpsq f1_qretbenchadjbps {
	reghdfe `v' rebalinadja rebalinadjd rebalouta rebaloutd ///
				actshare vwlannturn [aw=wtfund_cf], ///
	 		 noa vce(cluster yq permno fundno)
	if `a' == 1 {
		outreg2 using _regs/sfqreg_active_lowtna, replace
		local a=2
	}
	else{
		outreg2 using _regs/sfqreg_active_lowtna, append bdec(3)
	}
	reghdfe `v' rebalinadja rebalinadjd rebalouta rebaloutd ///
				actshare vwlannturn [aw=wtfund_cf], ///
	 		 	absorb(fundno yq) vce(cluster yq permno fundno)
	outreg2 using _regs/sfqreg_active_lowtna, append bdec(3)
	reghdfe `v' rebalinadja rebalinadjd  ///
				rebalouta rebaloutd [aw=wtfund_cf], ///
	 		 	absorb(fundno#yq) vce(cluster yq permno fundno)
	outreg2 using _regs/sfqreg_active_lowtna, append bdec(3)
}
restore

